@@ -7,10 +7,16 @@ has status_code => (
     is => 'ro',
     required => 1
 );
+#prior to activiti version 5.17, now exception
 has error_message => (
     is => 'ro',
     required => 1
 );
+#from activiti version 5.17, formerly errorMessage
+has exception => (
+    is => 'ro',
+    required => 1
+);
 has content_type => (
     is => 'ro',
     required => 1
